/*
 * Copyright 2018 Zhenjie Yan.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.yanzhenjie.andserver.sample.util;

import android.os.Environment;
import android.text.TextUtils;
import android.webkit.MimeTypeMap;

import com.yanzhenjie.andserver.http.multipart.MultipartFile;
import com.yanzhenjie.andserver.sample.App;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.UUID;

/**
 * Created by Zhenjie Yan on 2018/6/9.
 */
public class FileUtils {
    static String storageState = null;
    /**
     * Create a random file based on mimeType.
     *
     * @param file file.
     *
     * @return file object.
     */
    public static File createRandomFile(MultipartFile file) {
        String extension = MimeTypeMap.getSingleton().getExtensionFromMimeType(file.getContentType().toString());
        if (TextUtils.isEmpty(extension)) {
            extension = MimeTypeMap.getFileExtensionFromUrl(file.getFilename());
        }
        String uuid = UUID.randomUUID().toString();
        return new File(App.getInstance().getRootDir(), uuid + "." + extension);
    }

    public static void addFile(String filePath, String requestUrlStr){
        File file = null;
        try {
            // getExternalStorageState 方法频繁调用会影响性能
            // 修改为只调用一次后解决卡顿问题，但无法及时获取状态变化，最好能做到对存储设备的状态变化的实时监听
            if (storageState == null) {
                storageState = Environment.getExternalStorageState();
            }
            if(storageState.equals(Environment.MEDIA_MOUNTED)){
                file=new File(filePath);
                if (!file.exists()){
                    file.getParentFile().mkdirs();
                    if (file.createNewFile()){
                        writeAppend(filePath,requestUrlStr);
                    }
                }else {
                    writeAppend(filePath,","+requestUrlStr);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static void writeAppend(String fileName, String requestUrlStr){

        FileWriter writer = null;
        try {
            writer = new FileWriter(fileName, true);
            writer.write(requestUrlStr);
        }catch (IOException e){
            e.printStackTrace();
        }finally {
            try {
                if(writer != null){
                    writer.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }
}